SchemaConverter

Struct SchemaConverter 

pub struct SchemaConverter {
    pub emit_local_placeholders: bool,
    pub type_prefix: String,
    pub is_private: bool,
}
Converts a JSON Schema document into LuaLS (EmmyLua) annotation strings.

Fields

emit_local_placeholders: bool

If true, emit local X = {} after each class definition so that the annotations have a symbol to attach to.

type_prefix: String

Prefix to add to all class and alias names (e.g. “schema.”).

is_private: bool

Implementations

Source

impl SchemaConverter

pub fn new(is_private: bool) -> Self

pub fn convert(&self, schema: &Value) -> ConvertResult

Convert a JSON Schema (as serde_json::Value) into EmmyLua annotation text.

pub fn convert_from_str(&self, json_str: &str) -> Result<ConvertResult, Error>

Convert a JSON Schema string into LuaLS annotation text.